@@ -263,6 +263,22 @@ double showstack()
       value=p->value;  
       switch (base)
       {
+        case BIN: {
+		int bindigit;
+		char binstart = 0;
+
+		for (bindigit=0; bindigit<(sizeof(long int)*8); bindigit++) {
+			if (((unsigned long int)value << bindigit) & 
+			    (1 << (sizeof(long int)*8) -1)) {
+				printf("1");
+				binstart = 1;
+			} else {
+				if (binstart)
+					printf("0");
+			}
+		}
+		break;
+	}
         case HEX:  printf("0x%lx", (unsigned long int)value); break;
         case OCT:  printf("0%lo",  (signed long int)value); break;
 	case CHAR: {
@@ -323,3 +339,9 @@ double setchar(void)
   base = CHAR;
   return 0.0; /* dummy value */
 }
+
+double setbin(void) 
+{
+  base = BIN;
+  return 0.0; /* dummy value */
+}
